@@ -1,6 +1,7 @@
 from asyncio import Future, get_running_loop, wait_for
 from functools import partial
 from typing import Callable, Dict, List
+from uuid import uuid4
 
 from ..command import Command
 from ..constants import (CommandMethod, CommandStatus, CommonConstants,
@@ -63,6 +64,8 @@ class Channel(
     ) -> Command:
         loop = get_running_loop()
         future = loop.create_future()
+        if command.id is None:
+            command.id = str(uuid4())
         self.command_resolves[command.id] = future.set_result
 
         self.send_command(command)
@@ -156,6 +159,8 @@ class Channel(
         self.__send(envelope)
 
     def __send(self, envelope: Envelope) -> None:
+        if envelope.id is None:
+            envelope.id = str(uuid4())
         self.transport.send(envelope.to_json())
 
     def __notify_message(self, message: Message) -> None:
@@ -181,7 +186,7 @@ class Channel(
             command.id and \
             command.uri == CommonConstants.PING and \
             command.method == CommandMethod.GET and \
-            self.is_for_me(command)  # noqa: WPS222
+            self.__is_for_me(command)  # noqa: WPS222
 
     def __create_ping_command_reply(self, command: Command) -> Command:
         reply = Command(
